package com.java4less.android;

import com.java4less.j4lqrcode.QRCode;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.Paint.Style;
import android.view.View;

public class QRCodeView extends View {

	QRCode qrcode;
	int backColor=Color.WHITE;
	int foreColor=Color.BLACK;
	int moduleSize=4;
	int margin=20;
	
	public QRCodeView(Context context) {
		super(context);

	}	
	
	
	/**
	 * set margin in pixels
	 * @param s
	 */
	public void setMargin(int s) {
		margin=s;
	}
	
	/**
	 * get margin in pixels
	 * @return
	 */
	public int getMargin() {
		return margin;
	}	
	
	/**
	 * set size of modules (dots of the barcode)
	 * @param s
	 */
	public void setModuleSize(int s) {
		moduleSize=s;
	}
	
	/**
	 * get size of modules (dots of the barcode)
	 * @return
	 */
	public int getModuleSize() {
		return moduleSize;
	}	
	
	/**
	 * set background of the barcode
	 */
	public void setBackgroundColor(int c) {
		backColor=c;
	}
	
	/**
	 * set color of modules of the barcode
	 * @param c
	 */
	public void setForegroundColor(int c) {
		foreColor=c;
	}	
	
	/**
	 * get background of the barcode
	 * @return
	 */
	public int getBackgroundColor() {
		return backColor;
	}
	
	/**
	 * get color of modules of the barcode
	 * @return
	 */
	public int getForegroundColor() {
		return foreColor;
	}
	

	/**
	 * set QRCode object
	 * @param bc
	 */
	public void setQRCode(QRCode bc) {
		qrcode=bc;
	}
	
	/**
	 * get QRCode object
	 * @return
	 */
	public QRCode getQRCode() {
		return qrcode;
	}
	
	
	/**
	* control has been resized, resize chart
	*/
	protected void onSizeChanged(int w, int h, int oldw, int oldh) {
			super.onSizeChanged(w,h,oldw,oldh);
	}
		
	protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
		
		super.onMeasure(widthMeasureSpec,  heightMeasureSpec);
	}


	/**
	* paint barcode here
	*/ 
	public void onDraw(Canvas g) {
		// clear background
		Paint p=new Paint();
		p.setStyle(Style.FILL);
		p.setColor(backColor);
		g.drawRect(0,0,this.getWidth(),this.getHeight(),p);
		
		p=new Paint();
		p.setStyle(Style.FILL);
		p.setColor(foreColor);	
		
		
		   int[][] array=qrcode.paint();
		   int maxx=array[0].length;
		   int maxy=array.length;
		   for (int i=0;i<maxx;i++)
		       for (int j=0;j<maxy;j++)   {
		          int offsetI=(i)*moduleSize;
		          int offsetJ=(j)*moduleSize;
		          // paint module
		          if (array[j][i]==1)
		          {
		                    g.drawRect(offsetI+margin,offsetJ+margin,offsetI+moduleSize+margin,offsetJ+moduleSize+margin,p);
                   }
		       }

		
	}
			

}
